pub enum EventHandler<Dom>where
Dom: RealDom,{
NoArgs(Rc<RefCell<dyn FnMut()>>),
MouseEvent(Rc<RefCell<dyn FnMut(<Dom as RealDom>::MouseEvent)>>),
Custom(<Dom as RealDom>::EventCallback),
}Expand description
Event handlers such as the closure in onclick = |mouse_event| {}.
Variants
NoArgs(Rc<RefCell<dyn FnMut()>>)
A callback that does not contain any arguments.
MouseEvent(Rc<RefCell<dyn FnMut(<Dom as RealDom>::MouseEvent)>>)
Handle mouse events such as onclick and oninput
Custom(<Dom as RealDom>::EventCallback)
EventHandler’s that we do not have a dedicated type for. This is useful for custom events.