VirtualElement

Struct VirtualElement 

pub struct VirtualElement<Handle>
where Handle: RealDom,
{ pub tag: String, pub attrs: HashMap<String, AttributeValue>, pub events: Events<Handle>, pub children: Vec<VirtualNode<Handle>>, pub special_attributes: SpecialAttributes, }

Fields

tag: String

The HTML tag, such as “div”

attrs: HashMap<String, AttributeValue>

HTML attributes such as id, class, style, etc

events: Events<Handle>

Events that will get added to your real DOM element via .addEventListener

Events natively handled in HTML such as onclick, onchange, oninput and others can be found in [VElement.known_events]

children: Vec<VirtualNode<Handle>>

The children of this VirtualNode. So a

structure would have a parent div and one child, em.

special_attributes: SpecialAttributes

Implementations

Source

impl<Handle> VirtualElement<Handle>
where Handle: RealDom,

pub fn new(tag: impl Into<String>) -> VirtualElement<Handle>